==> PCI-DAS1602-16.1.0a.tgz: pci-das1602-16/pci-das1602.h <==
/*
 * Copyright (C) 1997  Warren Jasper
 * All rights reserved.
 *
 * This software may be freely copied, modified, and redistributed
 * provided that this copyright notice is preserved on all copies.
 *
 * You may not distribute this software, in whole or in part, as part of
 * any commercial product without the express consent of the authors.
 *
 * There is no warranty or other guarantee of fitness of this software
 * for any purpose.  It is provided solely "as is".
 *
 */

/*
 * pci-das1602.h
 */

/*  ioctl() values */

#define ADC_SET_GAINS        1
#define ADC_GET_GAINS        2
#define ADC_SET_PACER_FREQ   3
#define ADC_GET_PACER_FREQ   4
#define ADC_START_PACER      5
#define ADC_STOP_PACER       6
#define ADC_COUNTER0         7
#define ADC_DIO_PRESET       8
#define ADC_PACER_SOURCE     9
#define ADC_TRIGGER_SOURCE   10
#define ADC_SET_MUX_LOW      11
#define ADC_SET_MUX_HIGH     12
#define ADC_GET_CHAN_MUX_REG 13
#define ADC_SET_FRONT_END    14
#define ADC_BURST_MODE       15
#define ADC_SET_TGPOL        16
#define ADC_SET_TGSEL        17

#define DIO_SET_MODE         100
#define DIO_SET_DIRECTION    101

#define DAC_SET_GAINS        201
#define DAC_GET_GAINS        202
#define DAC_SET_PACER_FREQ   203
#define DAC_GET_PACER_FREQ   204
#define DAC_START_PACER      205
#define DAC_STOP_PACER       206

/* open mode values */

#define ADC_SOFT_CONVERT           (0x0)
#define ADC_EXTERNAL_PACER_FALLING (0x2)
#define ADC_EXTERNAL_PACER_RISING  (0x4)
#define ADC_PACER_CLOCK            (0x6)

#define DAC_SOFT_CONVERT           (0x1)
#define DAC_PACER_CLOCK            (0x5)
#define DAC_FALLING_EDGE           (0x3)
#define DAC_RISING_EDGE            (0x7)

/* Trigger Sources */
#define ADC_TRIG_DISABLE           (0x0)
#define ADC_TRIG_SW                (0x1)
#define ADC_TRIG_EXTERN_DIGITAL    (0x2)
#define ADC_TRIG_EXTERN_ANALOG     (0x3)

/* Digital I/O Modes */
#define MODE_IO            0
#define MODE_STROBE_IO     1
#define MODE_BIDIRECTIONAL 2

/* Digital I/O Direction Settings */
#define PORT_INPUT         1
#define PORT_OUTPUT        0
#define HIGH_PORT_INPUT    2
#define HIGH_PORT_OUTPUT   3
#define LOW_PORT_INPUT     4
#define LOW_PORT_OUTPUT    5


/* ioctl(COUNTER0) mode values */

#define CTR0_MODE0 (0x0 << 17)
#define CTR0_MODE1 (0x1 << 17)
#define CTR0_MODE2 (0x2 << 17)
#define CTR0_MODE3 (0x3 << 17)
#define CTR0_MODE4 (0x4 << 17)
#define CTR0_MODE5 (0x5 << 17)
#define CTR0_NOLOAD (0xff000000)

/*  General definitions */

#define MAX_AD_FREQ 200000
#define MAX_DA_FREQ 100000
#define BYTE unsigned char
#define WORD unsigned short
#define LONG unsigned long

/* Programmable Range and Gain Settings */

#define BP_10_00V  (0x00 << 8)    /* +/- 10V      */
#define BP_5_00V   (0x01 << 8)    /* +/-  5V      */
#define BP_2_50V   (0x02 << 8)    /* +/-  2.5V    */
#define BP_1_25V   (0x03 << 8)    /* +/-  1.25V   */
#define UP_10_00V  (0x08 << 8)    /* 0 - 10V      */
#define UP_5_00V   (0x09 << 8)    /* 0 - 5V       */
#define UP_2_50V   (0x0a << 8)    /* 0 - 2.5V     */
#define UP_1_25V   (0x0b << 8)    /* 0 - 1.25V    */

/* digital output */
#define DIO_0 0x1
#define DIO_1 0x2
#define DIO_2 0x4
#define DIO_3 0x8

==> PCI-DAS1602-16.1.1a.tgz: pci-das1602-16/pci-das1602.h <==
/*
 * Copyright (C) 1997  Warren Jasper
 * All rights reserved.
 *
 * This software may be freely copied, modified, and redistributed
 * provided that this copyright notice is preserved on all copies.
 *
 * You may not distribute this software, in whole or in part, as part of
 * any commercial product without the express consent of the authors.
 *
 * There is no warranty or other guarantee of fitness of this software
 * for any purpose.  It is provided solely "as is".
 *
 */

/*
 * pci-das1602.h
 */

/*  ioctl() values */

#define ADC_SET_GAINS        1
#define ADC_GET_GAINS        2
#define ADC_SET_PACER_FREQ   3
#define ADC_GET_PACER_FREQ   4
#define ADC_START_PACER      5
#define ADC_STOP_PACER       6
#define ADC_COUNTER0         7
#define ADC_DIO_PRESET       8
#define ADC_SET_TRIGGER      9
#define ADC_SET_MUX_LOW      10
#define ADC_SET_MUX_HIGH     11
#define ADC_GET_CHAN_MUX_REG 12
#define ADC_SET_FRONT_END    13
#define ADC_BURST_MODE       14
#define ADC_PRETRIG          15

#define DIO_SET_MODE         100
#define DIO_SET_DIRECTION    101

#define DAC_SET_GAINS        201
#define DAC_GET_GAINS        202
#define DAC_SET_PACER_FREQ   203
#define DAC_GET_PACER_FREQ   204
#define DAC_STOP_PACER       206
#define DAC_RECYCLE          207
#define DAC_SET_CLO          208
#define DAC_SET_CHI          209

/* open mode values (pacer source) */

#define ADC_SOFT_CONVERT           (0x0)
#define ADC_EXTERNAL_PACER_FALLING (0x2)
#define ADC_EXTERNAL_PACER_RISING  (0x4)
#define ADC_PACER_CLOCK            (0x6)

#define DAC_SOFT_CONVERT           (0x1)
#define DAC_PACER_CLOCK            (0x5)
#define DAC_FALLING_EDGE           (0x3)
#define DAC_RISING_EDGE            (0x7)

/* Digital I/O Modes */
#define MODE_IO            0
#define MODE_STROBE_IO     1
#define MODE_BIDIRECTIONAL 2

/* Digital I/O Direction Settings */
#define PORT_OUTPUT        0
#define PORT_INPUT         1
#define HIGH_PORT_INPUT    2
#define HIGH_PORT_OUTPUT   3
#define LOW_PORT_INPUT     4
#define LOW_PORT_OUTPUT    5

/* ioctl(COUNTER0) mode values */
#define CTR0_MODE0 (0x0 << 17)
#define CTR0_MODE1 (0x1 << 17)
#define CTR0_MODE2 (0x2 << 17)
#define CTR0_MODE3 (0x3 << 17)
#define CTR0_MODE4 (0x4 << 17)
#define CTR0_MODE5 (0x5 << 17)
#define CTR0_NOLOAD (0xff000000)

/*  General definitions */

#define MAX_AD_FREQ 200000
#define MAX_DA_FREQ 100000
#define BYTE unsigned char
#define WORD unsigned short
#define LONG unsigned long

/* Programmable Range and Gain Settings */

#define BP_10_00V  (0x00 << 8)    /* +/- 10V      */
#define BP_5_00V   (0x01 << 8)    /* +/-  5V      */
#define BP_2_50V   (0x02 << 8)    /* +/-  2.5V    */
#define BP_1_25V   (0x03 << 8)    /* +/-  1.25V   */
#define UP_10_00V  (0x08 << 8)    /* 0 - 10V      */
#define UP_5_00V   (0x09 << 8)    /* 0 - 5V       */
#define UP_2_50V   (0x0a << 8)    /* 0 - 2.5V     */
#define UP_1_25V   (0x0b << 8)    /* 0 - 1.25V    */

/* DAC MODES */
#define ONE_SHOT    0x0
#define CONTINUOUS  0x1

/* digital output */
#define DIO_0 0x1
#define DIO_1 0x2
#define DIO_2 0x4
#define DIO_3 0x8

/* Set Trigger Values  */
#define GATE_NEG_HYS    1
#define GATE_POS_HYS    2
#define GATE_ABOVE      3
#define GATE_BELOW      4
#define TRIG_ABOVE      5
#define TRIG_BELOW      6
#define GATE_OUT_WINDOW 7
#define GATE_IN_WINDOW  8
#define GATE_HIGH       9
#define GATE_LOW        10
#define TRIG_POS_EDGE   11
#define TRIG_NEG_EDGE   12
